<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui name="contactthemeeditor" version="2">
 <MenuBar>
  <Menu name="file" >
   <Action name="new_theme" />
   <Separator />
   <Action name="load_recent_theme" />
   <Separator />
   <Action name="insert_file" />
   <Separator />
   <Action name="upload_theme"/>
   <Separator />
   <Action name="manage_themes"/>
  </Menu>
  <Menu noMerge="1" name="edit" >
   <text>&amp;Edit</text>
   <Action name="add_extra_page" />
   <Separator />
   <Action name="install_theme" />
  </Menu>
  <Menu name="Display" >
   <text>&amp;Display</text>
   <Action name="update_view" />
  </Menu>
 </MenuBar>
 <ToolBar name="mainToolBar" fullWidth="true" >
   <Action name="update_view" />
 </ToolBar>
</gui>

