/*
   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#ifndef THEMEDEFAULTTEMPLATE_H
#define THEMEDEFAULTTEMPLATE_H

#include <PimCommon/TemplateListWidget>

namespace ThemeDefaultTemplate {
Q_REQUIRED_RESULT QVector<PimCommon::defaultTemplate> defaultTemplates();
}

#endif // THEMEDEFAULTTEMPLATE_H
