/*
   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/
#include "contactdefaulttemplate.h"

QVector<PimCommon::defaultTemplate> ContactDefaultTemplate::contactTemplates()
{
    return QVector<PimCommon::defaultTemplate>();
    /*
    PimCommon::defaultTemplate tmp;
    //TODO
    lst << tmp;
    */
}
